==> kdebase-1.90.tar.bz2: kdebase-1.90/kicker/panelbuttonbase.h <==
/*****************************************************************

Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __panelbuttonbase_h__
#define __panelbuttonbase_h__

#include <qbutton.h>
#include <qpixmap.h>
#include <qcursor.h>

#include "global.h"

class PanelButtonBase : public QButton
{
  Q_OBJECT;

 public:
  PanelButtonBase(QWidget *parent=0, const char *name=0);

  void setTile(const QString&);
  void setIcon(const QPixmap&);

  void setHighlightOnMouseOver(bool);
  void setDrawArrow(bool);
  void setArrowDirection(Position dir);

 protected slots:
  void slotSettingsChanged(int);

 protected:
  virtual void resizeEvent(QResizeEvent*);
  virtual void drawButton(QPainter *);
  virtual void drawButtonLabel(QPainter *);
  virtual void enterEvent(QEvent *);
  virtual void leaveEvent(QEvent *);

  void loadTiles();

  Position _dir;
  bool _drawArrow, _highlight, _dohighlight, _changeCursorOverItem;
  QString _tile;
  QCursor oldCursor;
  QPixmap _up, _down, _icon, _iconh;
};


#endif // __hidebutton_h__

==> kdebase-1.91.tar.bz2: kdebase-1.91/kicker/panelbuttonbase.h <==
/*****************************************************************

Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __panelbuttonbase_h__
#define __panelbuttonbase_h__

#include <qbutton.h>
#include <qpixmap.h>
#include <qcursor.h>

#include <kurl.h>

#include "global.h"

class PanelButtonBase : public QButton
{
  Q_OBJECT;

 public:
  PanelButtonBase(QWidget *parent=0, const char *name=0);

  void setTile(const QString&);
  void setIcon(const QString & name, const QString & fallback);
  void setIcon(const KURL & url);

  void setDrawArrow(bool);
  void setArrowDirection(Position dir);

 protected slots:
  void slotSettingsChanged(int);

 protected:
  virtual void resizeEvent(QResizeEvent*);
  virtual void drawButton(QPainter *);
  virtual void drawButtonLabel(QPainter *);
  virtual void enterEvent(QEvent *);
  virtual void leaveEvent(QEvent *);

  void loadTiles();

  Position _dir;
  bool _drawArrow, _highlight, _changeCursorOverItem;
  QString _tile;
  QCursor oldCursor;
  QPixmap _up, _down, _icon, _iconh;
};


#endif // __hidebutton_h__
